import React, { useState } from "react";
import { NodeType, NodeTypeData } from "../../common/graph/nodetype";
import "./nodetypeentry.css";

type NodeTypeEntryProps = {
    nodeType: NodeType;
    onNodeTypeDelete: (id: number[]) => void;
    onNodeTypeDataChange: (
        requests: NodeTypeData[],
        createCheckpoint?: boolean
    ) => void;
    onNodeTypeSelect: (type: NodeType) => void;
    enableDelete: boolean;
    createCheckpoint: (description: string) => void;
};

function NodeTypeEntry({
    nodeType,
    onNodeTypeDataChange,
    onNodeTypeDelete,
    onNodeTypeSelect,
    enableDelete,
    createCheckpoint,
}: NodeTypeEntryProps) {
    const [tmpColor, setTmpColor] = useState<string>(undefined);

    const isValidColor = (color: string) => {
        if (color.length <= 0) {
            return false;
        }

        // Source: https://stackoverflow.com/a/8027444
        return /^#([0-9A-F]{3}){1,2}$/i.test(color);
    };

    const referenceData: NodeTypeData = {
        id: nodeType.id,
        color: nodeType.color,
        name: nodeType.name,
    };

    const handleDataChange = function <ValueType>(
        key: keyof NodeTypeData,
        value: ValueType
    ) {
        if (!changed) {
            setChanged(true);
        }

        Object.assign(referenceData, { [key]: value });
        onNodeTypeDataChange([referenceData], false);
    };

    const handleColorChange = (color: string) => {
        if (isValidColor(color)) {
            handleDataChange("color", color);
            setTmpColor(undefined);
        } else {
            setTmpColor(color);
        }
    };

    const [changed, setChanged] = useState(false);

    const handleBlur = () => {
        if (changed) {
            createCheckpoint(`Modified node type ${nodeType.name}.`);
            setChanged(false);
        }
    };

    return (
        <li className="node-type" onBlur={handleBlur}>
            <input
                className="node-type-name"
                type={"text"}
                value={nodeType.name}
                onChange={(event) =>
                    handleDataChange("name", event.target.value)
                }
            />
            <input
                className="node-type-color"
                type={"text"}
                value={tmpColor !== undefined ? tmpColor : nodeType.color}
                onChange={(event) => handleColorChange(event.target.value)}
            />
            <button onClick={() => onNodeTypeSelect(nodeType)}>
                Select nodes
            </button>
            {enableDelete && (
                <button onClick={() => onNodeTypeDelete([nodeType.id])}>
                    Delete
                </button>
            )}
        </li>
    );
}

export default NodeTypeEntry;
