import React from "react";
import "./nodetypeseditor.css";
import NodeTypeEntry from "./nodetypeentry";
import { NodeType, NodeTypeData } from "../../common/graph/nodetype";

type NodeTypesEditorProps = {
    nodeTypes: NodeType[];
    onNodeTypeSelect: (type: NodeType) => void;
    onNodeTypeCreation: () => NodeType;
    onNodeTypeDelete: (id: number[]) => void;
    onNodeTypeDataChange: (
        requests: NodeTypeData[],
        createCheckpoint?: boolean
    ) => void;
    createCheckpoint: (description: string) => void;
};

function NodeTypesEditor({
    nodeTypes,
    onNodeTypeSelect,
    onNodeTypeCreation,
    onNodeTypeDelete,
    onNodeTypeDataChange,
    createCheckpoint,
}: NodeTypesEditorProps) {
    return (
        <div id="node-types-editor">
            <h3>Node types</h3>
            <ul>
                {nodeTypes.map((nodeType) => (
                    <NodeTypeEntry
                        key={nodeType.id}
                        nodeType={nodeType}
                        onNodeTypeSelect={onNodeTypeSelect}
                        onNodeTypeDelete={onNodeTypeDelete}
                        onNodeTypeDataChange={onNodeTypeDataChange}
                        enableDelete={nodeTypes.length > 1}
                        createCheckpoint={createCheckpoint}
                    />
                ))}
            </ul>
            <button onClick={onNodeTypeCreation}>Add type</button>
        </div>
    );
}

export default NodeTypesEditor;
